<?php

namespace App\Controller;

use App\Gateway\AuthGateway;
use App\Http\HttpRequest;
use App\Http\HttpResponse;
use App\Http\ViewHttpResponse;
use App\Model\AuthModel;
use App\Validation\FieldValidationFail;
use App\Validation\Validators;
use Twig\Environment;


class AuthController {
    private AuthModel $model;

    /**
     * @param AuthModel $model
     */
    public function __construct(AuthModel $model) {
        $this->model = $model;
    }

    public function displayRegister(): HttpResponse {
        return ViewHttpResponse::twig("display_register.html.twig", []);
    }

    public function confirmRegister(array $request): HttpResponse {

        $fails = [];
        $request = HttpRequest::from($request, $fails, [
            "username" => [Validators::name(), Validators::lenBetween(0, 32)],
            "password" => [Validators::lenBetween(0, 256)],
            "confirmpassword" => [Validators::lenBetween(0, 256)],
            "email" => [Validators::regex("/@/")]
        ]);


        if (!empty($fails)) {
            $bad_fields = [];
            foreach ($fails as $err) {
                if ($err instanceof FieldValidationFail) {
                    $bad_fields[] = $err->getFieldName();
                }
            }
            return ViewHttpResponse::twig("display_register.html.twig", ['bad_fields' => $bad_fields]);
        }

        $fails = $this->model->validationRegister($request['username'], $request["password"], $request['confirmpassword'], $request['email']);
        if (empty($fails)) {
            $results = $this->model->getUserFields($request['email']);
            return ViewHttpResponse::twig("display_register_confirm.html.twig", ['username' => $results['username'], 'email' => $results['email']]);
        }

        $bad_fields = [];
        foreach ($fails as $err) {
            if ($err instanceof FieldValidationFail) {
                $bad_fields[] = $err->getFieldName();
            }
        }
        return ViewHttpResponse::twig("display_register.html.twig", ['bad_fields' => $bad_fields]);
    }
//GARDER LES EMAIL ET USERNAME ET REGLER SURLIGNAGE DES MDP QUAND CA VA PAS

}